@@ -1,15 +1,12 @@
-##################
-# default config #
-##################
 $config = {
-  'config_dir'            => Path::find_home + '/.raggle',
+  'config_dir'            => Raggle::Path::find_home + '/.raggle',
   'config_path'           => '${config_dir}/config.rb',
   'feed_list_path'        => '${config_dir}/feeds.yaml',
   'feed_cache_path'       => '${config_dir}/feed_cache.store',
   'theme_path'            => '${config_dir}/theme.yaml',
   'grab_log_path'         => '${config_dir}/grab.log',
   'cache_lock_path'       => '${config_dir}/lock',
-  'web_ui_root_path'      => Path::find_web_ui_root,
+  'web_ui_root_path'      => Raggle::Path::find_web_ui_root,
   'web_ui_log_path'       => '${config_dir}/webrick.log',
 
   # feed list handling
@@ -26,6 +23,9 @@ $config = {
   # to use the per-feed --save-items command-line option.
   'save_feed_items'       => false,
 
+  # confirm feed deletion?
+  'confirm_delete'        => true,
+
   # theme handling
   'load_theme'            => true,
   'save_theme'            => true,
@@ -51,7 +51,7 @@ $config = {
   'use_ascii_only?'       => false,
 
   # maximum number of threads (don't set to less than 5!)
-  'max_threads'           => 7,
+  'max_threads'           => 10,
 
   # thread priorities (best to leave these alone)
   'thread_priority_main'  => 10,
@@ -59,6 +59,8 @@ $config = {
   'thread_priority_grab'  => 0, # child grabbing threads
   'thread_priority_gc'    => 1,
   'thread_priority_http'  => 1,
+  'thread_priority_find'  => 1,
+  'thread_priority_save'  => 0,
 
   # grab thread reap timeout (wait up to N seconds)
   'thread_reap_timeout'   => 120,
@@ -82,10 +84,10 @@ $config = {
 
   # URL handlers
   'url_handlers'          => {
-    'http'      => proc { |url, last_mod| Feed::get_http_url(url, last_mod) },
-    'https'     => proc { |url, last_mod| Feed::get_http_url(url, last_mod) },
-    'file'      => proc { |url, last_mod| Feed::get_file_url(url, last_mod) },
-    'exec'      => proc { |url, last_mod| Feed::get_exec_url(url, last_mod) },
+    'http'      => proc { |url, last_mod| Raggle::Engine::get_http_url(url, last_mod) },
+    'https'     => proc { |url, last_mod| Raggle::Engine::get_http_url(url, last_mod) },
+    'file'      => proc { |url, last_mod| Raggle::Engine::get_file_url(url, last_mod) },
+    'exec'      => proc { |url, last_mod| Raggle::Engine::get_exec_url(url, last_mod) },
   },
 
   # Raise an exception (which generally means crash) if the URL type is
@@ -106,7 +108,7 @@ $config = {
     # yes Richard, there is a reason the following line looks so
     # ugly. -- Paul
     'Accept-Charset'      =>'ISO-8859-1,UTF-8;q=0.7,*;q=0.7',
-    'User-Agent'          => "Raggle/#$VERSION (#{PLATFORM}; Ruby/#{VERSION})",
+    'User-Agent'          => "Raggle/#$VERSION (#{RUBY_PLATFORM}; Ruby/#{RUBY_VERSION})",
   },
 
   # Number of list items per "page" (wrt page up/down)
@@ -153,10 +155,32 @@ $config = {
   'msg_load_theme'        => 'Raggle: Loading theme...',
   'msg_save_theme'        => 'Raggle: Saving theme...',
   'msg_thanks'            => 'Thanks for using Raggle!',
+  'msg_default_input'     => 'Input:',
+  'msg_new_value'         => 'New value:',
   'msg_term_resize'       => 'Terminal Resize: ',
   'msg_links'             => 'Links:',
+  'msg_images'            => 'Images:',
   'msg_add_feed'          => 'Enter URL:',
+  'msg_feed_added'        => 'Feed added',
+  'msg_confirm_delete'    => 'Delete current feed? (y/n)',
   'msg_find_entry'        => 'Find:',
+  'msg_cat_title'         => 'Display Category',
+  'msg_find_feed'         => 'Find Feeds:',
+  'msg_searching'         => ' Searching...',
+  'msg_find_title'        => 'Search Results for "%s" - %s matching feeds',
+  'msg_find_desc'         => 'Please select a feed...',
+  'msg_find_nomatches'    => 'No results found',
+  'msg_keys_title'        => 'Current Key Bindings',
+  'msg_added_existing'    => 'Warning: Added existing feed',
+  'msg_edit_title'        => 'Edit Feed Options',
+  'msg_bad_option'        => 'Warning: Bad option for %s',
+  'msg_edit_success'      => 'New option saved',
+  'msg_save_done'         => 'Configuration saved',
+  'msg_opml_input'        => 'OPML file or URI:',
+  'msg_opml_exported'     => 'OPML exported',
+  'msg_opml_imported'     => 'OPML imported',
+  'msg_bad_uri'           => 'Error: bad or empty URI',
+  'msg_exec_url'          => 'WARNING: exec url found!',
 
   # menu bar color
   'menu_bar_cols'         => 24,
@@ -175,9 +199,15 @@ $config = {
   # thread sleep intervals (in seconds)
   'feed_sleep_interval'   => 60,
 
+  # save thread sleep interval (in seconds)
+  'save_sleep_interval'   => 300,
+
   # gc thread sleep interval (in seconds)
   'gc_sleep_interval'     => 600,
 
+  # max results to return from syndic8
+  'syndic8_max_results'   => 100,
+
   # grab log mode (a == append, w == write)
   'grab_log_mode'         => 'w',
 
@@ -197,20 +227,62 @@ $config = {
   'force_text_wrap'       => false,
 
   # replace unicode chars with what?
+  #
+  # Note: this option is meaningless when iconv character encoding
+  # translation is enabled, unless 'use_iconv_munge' is true.
   'unicode_munge_str'     => '!u!',
 
-  # character encoding used to display text
-  # from RSS feeds.
+  # character encoding used to display text from RSS feeds.
+  #
+  # The allowed values for 'character_encoding' vary depending on the
+  # character encoding method.  If you're using the pre-0.4.0
+  # REXML-style encoding translation (and you really shouldn't be unless
+  # you're having problems; see 'use_iconv' below for additional
+  # information), then the supported values are as follows:
+  # 
+  #   ISO-8859-1, UTF-8, UTF-16 and UNILE
+  #
+  # On the other hand, if you're using iconv-style encoding translation,
+  # the list of allowed values is any character encoding supported by 
+  # your version of iconv (use "iconv --list" for a full list).  Be sure
+  # to omit the trailing '//' from your character_encoding value; Raggle
+  # automatically appends it if it's necessary.
   #
-  # Supported encodings are: ISO-8859-1, UTF-8, UTF-16 and UNILE
   'character_encoding'    => 'ISO-8859-1',
 
+  # iconv support 
+  # 
+  # This is the new character encoding support.  If iconv is installed
+  # and iconv support is enabled (with 'use_iconv'), then use iconv
+  # instead of REXML to do character encoding translations.  If
+  # 'use_iconv_translit' is enabled, then use iconv transliteration to
+  # approximate characters that cannot be directly represented in the
+  # character encoding (specified above in 'character_encoding').
+  #
+  # Both 'use_iconv' and 'use_iconv_translit' default to true.
+  #
+  # If you've got iconv installed, you really should be using it to do
+  # character conversions.  It's faster than REXML, supports a much
+  # broader range of character encodings, and has intelligent built-in 
+  # transliteration (as opposed to the unicode_munge_str chicanery
+  # Raggle uses for the REXML-style encoding translation).
+  #
+  # It's probably a good idea to leave transliteration enabled.  It will
+  # prevent iconv from barfing on characters it can't translate, and,
+  # since Ncurses-Ruby doesn't have wide character support, it will keep
+  # Ncurses from printing garbage all over the screen. 
+  # 
+  'use_iconv'             => true,
+  'use_iconv_translit'    => true,
+  'use_iconv_munge'       => false,
+
   # warn if feed refresh is set to less than this
   'feed_refresh_warn'     => 60,
 
   # default feed name and refresh rate
   'default_feed_title'    => 'Untitled Feed',
   'default_feed_refresh'  => 120,
+  'default_feed_priority' => 0,
 
   # open new screen window for browser?
   'use_screen'            => true,
@@ -219,13 +291,16 @@ $config = {
   'screen_cmd'            => ['screen', '-t', '%s'],
   
   # browser options
-  'browser'               => Path::find_browser,
+  'browser'               => Raggle::Path::find_browser,
   'browser_cmd'           => ['${browser}', '%s'],
 
+  # beep on new articles?
+  'do_beep'               => false,
+
   # Force raggle to accept shell metacharacters in urls.
   'force_url_meta'        => false,
   # Regular expression matching shell metacharacters to not allow in URLs
-  'shell_meta_regex'       => /([\`\$]|\#\{)/, # the #{ is to stop ruby
+  # 'shell_meta_regex'       => /([\`\$]|\#\{)/, # the #{ is to stop ruby
                                               # expansion.
                                               # Is that necessary?
 
@@ -259,65 +334,95 @@ $config = {
 
   # key bindings
   'keys'            => ($HAVE_LIB['ncurses'] ? {
-    Ncurses::KEY_RIGHT  => proc { |win, key| Key::next_window },
-    ?\t                 => proc { |win, key| Key::next_window },
+    Ncurses::KEY_RIGHT  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::next_window} ),
+    ?\t                 => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::next_window} ),
 
-    Ncurses::KEY_LEFT   => proc { |win, key| Key::prev_window },
-    ?\\                 => proc { |win, key| Key::view_source },
+    Ncurses::KEY_LEFT   => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::prev_window} ),
+    ?\\                 => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::view_source} ),
 
-    Ncurses::KEY_F12    => proc { |win, key| Key::quit },
-    ?q                  => proc { |win, key| Key::quit },
+    Ncurses::KEY_F12    => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::quit} ),
+    ?q                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::quit} ),
 
-    Ncurses::KEY_UP     => proc { |win, key| Key::scroll_up },
-    Ncurses::KEY_DOWN   => proc { |win, key| Key::scroll_down },
-    Ncurses::KEY_HOME   => proc { |win, key| Key::scroll_top },
-    ?0                  => proc { |win, key| Key::scroll_top },
-    Ncurses::KEY_END    => proc { |win, key| Key::scroll_bottom },
-    ?$                  => proc { |win, key| Key::scroll_bottom },
-    Ncurses::KEY_PPAGE  => proc { |win, key| Key::scroll_up_page },
-    Ncurses::KEY_NPAGE  => proc { |win, key| Key::scroll_down_page },
+    Ncurses::KEY_UP     => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_up} ),
+    Ncurses::KEY_DOWN   => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_down} ),
+    Ncurses::KEY_HOME   => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_top} ),
+    ?0                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_top} ),
+    Ncurses::KEY_END    => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_bottom} ),
+    ?$                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_bottom} ),
+    Ncurses::KEY_PPAGE  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_up_page} ),
+    Ncurses::KEY_NPAGE  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_down_page} ),
 
     # vi keybindings
-    ?h                  => proc { |win, key| Key::prev_window },
-    ?j                  => proc { |win, key| Key::scroll_down },
-    ?k                  => proc { |win, key| Key::scroll_up },
-    ?l                  => proc { |win, key| Key::next_window },
+    ?h                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::prev_window} ),
+    ?j                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_down} ),
+    ?k                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_up} ),
+    ?l                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::next_window} ),
+    ?g                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_top} ),
+    ?G                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::scroll_bottom} ),
 
-    ?\n                 => proc { |win, key| Key::select_item },
-    ?\                  => proc { |win, key| Key::select_item },
+    ?\n                 => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::select_item} ),
+    ?\                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::select_item} ),
 
-    ?u                  => proc { |win, key| Key::move_item_up },
-    ?d                  => proc { |win, key| Key::move_item_down },
+    ?u                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::move_feed_up} ),
+    ?d                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::move_feed_down} ),
 
-    ?I                  => proc { |win, key| Key::invalidate_feed },
+    ?I                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::invalidate_feed} ),
+    ?e                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::edit_feed} ),
 
-    ?/                  => proc { |win, key| Key::find_entry(win) },
+    ?/                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::find_entry(win)} ),
 
-    Ncurses::KEY_DC     => proc { |win, key| Key::delete },
+    Ncurses::KEY_DC     => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::delete} ),
+    ?y                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::undelete_all} ),
     ##
     # XXX: Meta can be dropped after spawned browser exits
     # So A, B, C or D should *not* be bound until this is fixed
     # -- richlowe 2003-06-22 (actually --pabs 2003-06-21)
-    # ?D                  => proc { |win, key| Key::delete },
+    # ?D                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::delete} ),
 
 
     # Literal control L is horrid -- richlowe 2003-06-26
-    ?\                => proc { |win, key| resize_term },
-    Ncurses::KEY_RESIZE => proc { |win, key| resize_term },
+    ?\                => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::resize_term} ),
 
-    ?s                  => proc { |win, key| Key::sort_feeds },
+    ?s                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::sort_feeds} ),
 
-    ?o                  => proc { |win, key| Key::open_link },
+    ?o                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::open_link} ),
 
-    ?m                  => proc { |win, key| mark_items_as_read },
+    ?m                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::mark_items_as_read} ),
+    ?M                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::mark_items_as_unread} ),
+    ?N                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::mark_current_as_unread} ),
 
-    ?!                  => proc { |win, key| drop_to_shell },
+    ?!                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::drop_to_shell} ),
 
-    ?p                  => proc { |win, key| select_prev_unread },
-    ?n                  => proc { |win, key| select_next_unread },
+    ?p                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::select_prev_unread} ),
+    ?n                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::select_next_unread} ),
 
-    ?U                  => proc { |win, key| Key::manual_update },
-    ?a                  => proc { |win, key| Key::gui_add_feed },
+    ?r                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::lower_feed_priority} ),
+    ?R                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::raise_feed_priority} ),
+
+    ?U                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::manual_update} ),
+    ?S                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::manual_save} ),
+    ?a                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::add_feed} ),
+    ?O                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::opml} ),
+
+    # i know this is using 'c'.. we'll see if this fucks us (see note
+    # about 'C' above)
+    # -- pabs (Sat Mar 20 21:10:55 2004)
+    ?c                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::gui_cat_list} ),
+    ?f                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::gui_find_feed} ),
+    ?C                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::close_window} ),
+    ?                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::close_window} ),
+
+    ??                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::show_key_bindings} ),
+
+    ?1                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::open_link(1)} ),
+    ?2                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::open_link(2)} ),
+    ?3                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::open_link(3)} ),
+    ?4                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::open_link(4)} ),
+    ?5                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::open_link(5)} ),
+    ?6                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::open_link(6)} ),
+    ?7                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::open_link(7)} ),
+    ?8                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::open_link(8)} ),
+    ?9                  => proc( %{|win, key| Raggle::Interfaces::NcursesInterface::Key::open_link(9)} ),
   } : {}),
 
   # color palette (referenced by themes)
@@ -446,14 +551,14 @@ $config = {
   },
 
   # live feeds
-  'feeds'    => FeedList.new,
+  'feeds'    => Raggle::Feed::List.new,
 
   # debugging / internal options (don't touch)
   'use_raw_mode'  => true,
   'use_noecho'    => true,
 
   'default_feeds' => [
-    { 'title'     => '  Raggle Help', # add a space so sorting puts it at top
+    { 'title'     => 'Raggle Help',
       'url'       => "http://www.raggle.org/rss/help/",
       'site'      => 'http://www.raggle.org/',
       'refresh'   => 240,
@@ -461,6 +566,7 @@ $config = {
       'desc'      => '',
       'category'  => 'Raggle',
       'items'     => [ ],
+      'priority'  => 2,
     },
     { 'title'     => 'Alternet',
       'url'       => 'http://www.alternet.org/rss/rss.xml',
@@ -468,7 +574,7 @@ $config = {
       'desc'      => 'Alternative News and Information.',
       'refresh'   => 120,
       'updated'   => 0,
-      'category'  => 'Politics,News',
+      'category'  => 'Politics News',
       'items'     => [ ],
     },
     { 'title'     => 'Daily Daemon News',
@@ -481,7 +587,7 @@ $config = {
       'items'     => [ ],
     },
     { 'title'     => 'FreshMeat',
-      'url'       => 'http://themes.freshmeat.net/backend/fm-newsletter.rdf',
+      'url'       => 'http://download.freshmeat.net/backend/fm-newsletter.rdf',
       'site'      => 'http://www.freshmeat.net/',
       'desc'      => 'FreshMeat.',
       'refresh'   => 120,
@@ -489,6 +595,15 @@ $config = {
       'category'  => 'Tech',
       'items'     => [ ],
     },
+    { 'title'     => 'Half Full.org',
+      'url'       => 'http://halffull.org/feed/',
+      'site'      => 'http://halffull.org/',
+      'desc'      => 'Thomas Kirchner\'s personal site.',
+      'refresh'   => 120,
+      'updated'   => 0,
+      'category'  => 'Blogs Tech',
+      'items'     => [ ],
+    },
     { 'title'     => 'KernelTrap',
       'url'       => 'http://kerneltrap.org/node/feed',
       'site'      => 'http://www.kerneltrap.org/',
@@ -508,7 +623,7 @@ $config = {
       'items'     => [ ],
     },
     { 'title'     => 'Linux Weekly News',
-      'url'       => 'http://www.lwn.net/headlines/rss',
+      'url'       => 'http://www.lwn.net/headlines/newrss',
       'site'      => 'http://www.lwn.net/',
       'desc'      => 'Linux Weekly News',
       'refresh'   => 120,
@@ -516,10 +631,10 @@ $config = {
       'category'  => 'Tech',
       'items'     => [ ],
     },
-    { 'title'     => 'Linuxbrit.co.uk',
-      'url'       => 'http://www.linuxbrit.co.uk/rss.php',
+    { 'title'     => 'Linuxbrit',
+      'url'       => 'http://www.linuxbrit.co.uk/feed/rss2/',
       'site'      => 'http://www.linuxbrit.co.uk/',
-      'desc'      => 'Linuxbrit.co.uk',
+      'desc'      => 'Tom Gilbert\'s personal site.',
       'refresh'   => 120,
       'updated'   => 0,
       'category'  => 'Blogs',
@@ -543,32 +658,15 @@ $config = {
       'category'  => 'Blogs',
       'items'     => [ ],
     },
-    { 'title'     => 'Pigdog Journal',
-      'url'       => 'http://www.pigdog.org/pigdog.rdf',
-      'site'      => 'http://www.pigdog.org/',
-      'desc'      => 'Pigdog Journal',
-      'refresh'   => 120,
-      'updated'   => 0,
-      'category'  => 'Politics,News',
-      'items'     => [ ],
-    },
     { 'title'     => 'Raggle: News',
       'url'       => 'http://raggle.org/rss/',
-      'site'      => 'http://www.raggle.org/',
+      'site'      => 'http://raggle.org/',
       'desc'      => 'Raggle News',
       'refresh'   => 120,
       'updated'   => 0,
-      'category'  => 'Tech,Raggle',
-      'items'     => [ ],
-    },
-    { 'title'     => 'Richlowe.net',
-      'url'       => 'http://richlowe.net/diary/index.rss',
-      'site'      => 'http://www.richlowe.net/',
-      'desc'      => 'Richlowe.net',
-      'refresh'   => 120,
-      'updated'   => 0,
-      'category'  => 'Blogs',
+      'category'  => 'Tech Raggle',
       'items'     => [ ],
+      'priority'  => 1,
     },
     { 'title'     => 'Slashdot',
       'url'       => 'http://slashdot.org/slashdot.rss',
@@ -576,7 +674,7 @@ $config = {
       'desc'      => 'Slashdot',
       'refresh'   => 120,
       'updated'   => 0,
-      'category'  => 'Tech,News',
+      'category'  => 'Tech News',
       'items'     => [ ],
     },
     { 'title'     => 'This Modern World',
@@ -585,16 +683,7 @@ $config = {
       'desc'      => 'This Modern World',
       'refresh'   => 120,
       'updated'   => 0,
-      'category'  => 'Blogs,Politics',
-      'items'     => [ ],
-    },
-    { 'title'     => 'Tynian.net',
-      'url'       => 'http://tynian.net/rss/',
-      'site'      => 'http://tynian.net/',
-      'desc'      => 'tynian.net',
-      'refresh'   => 120,
-      'updated'   => 0,
-      'category'  => 'Blogs',
+      'category'  => 'Blogs Politics',
       'items'     => [ ],
     },
     { 'title'     => 'W3C',
@@ -612,7 +701,7 @@ $config = {
       'desc'      => 'yahoo tech',
       'refresh'   => 120,
       'updated'   => 0,
-      'category'  => 'Tech,News',
+      'category'  => 'Tech News',
       'items'     => [ ],
     },
     { 'title'     => 'Yahoo! News - Top Stories',
@@ -630,7 +719,7 @@ $config = {
       'desc'      => 'yahoo world',
       'refresh'   => 120,
       'updated'   => 0,
-      'category'  => 'Politics,News',
+      'category'  => 'Politics News',
       'items'     => [ ],
     },
   ],
